@@ -3,6 +3,8 @@
 use FindBin;
 use lib "$FindBin::Bin/../lib";
 
+use Site;
 use Demo;
 use Strehler::Admin;
+use Strehler::API;
 Demo->dance;
